@@ -19,7 +19,7 @@
 
 #include <KIO/CommandLauncherJob>
 
-K_EXPORT_PLASMA_RUNNER_WITH_JSON(KateSessions, "plasma-runner-katesessions.json")
+K_PLUGIN_CLASS_WITH_JSON(KateSessions, "plasma-runner-katesessions.json")
 
 KateSessions::KateSessions(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args)
     : Plasma::AbstractRunner(parent, metaData, args)
